GitStatusEntry

Struct GitStatusEntry 

pub struct GitStatusEntry {
    pub staged: u8,
    pub unstaged: u8,
    pub flags: u8,
    pub oid: GitOid,
    pub old_path: String,
    pub path: String,
}
One index/worktree status entry.

Fields

staged: u8unstaged: u8flags: u8oid: GitOid

The worktree content hash when the status walk read the file, else zero. A change that leaves the letters alone still moves this.

old_path: String

Non-empty only for renames.

path: String